==> cg-45.4.4.tar.gz: cg-45.4.4/tests/meta/clean/conftest.py <==
from pathlib import Path

import pytest


@pytest.fixture(name="correct_flow_cell_name", scope="function")
def fixture_correct_flow_cell_name(bcl2fastq_flow_cell_full_name: str) -> str:
    """Correct flow cell name."""
    return bcl2fastq_flow_cell_full_name


@pytest.fixture(name="incorrect_flow_cell_too_long", scope="function")
def fixture_incorrect_flow_cell_too_long(correct_flow_cell_name: str) -> str:
    """Incorrect flow cell name."""
    return correct_flow_cell_name + "_r"


@pytest.fixture(name="incorrect_flow_cell_extension", scope="function")
def fixture_incorrect_flow_cell_extension(correct_flow_cell_name: str) -> str:
    """Incorrect flow cell name."""
    return correct_flow_cell_name + ".someextension"


@pytest.fixture(name="incorrect_flow_cell_name", scope="function")
def fixture_incorrect_flow_cell_name() -> str:
    """Incorrect flow cell name."""
    return "201203_A00689_0200_AZZZZZZZZZ"


@pytest.fixture(name="correct_flow_cell_path", scope="function")
def fixture_correct_flow_cell_path(
    tmp_demultiplexed_runs_directory: Path, correct_flow_cell_name: str
) -> Path:
    """Full path to a correctly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, correct_flow_cell_name)


@pytest.fixture(name="incorrect_flow_cell_path_too_long", scope="function")
def fixture_incorrect_flow_cell_path_too_long(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_too_long: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_too_long)


@pytest.fixture(name="incorrect_flow_cell_path_extension", scope="function")
def fixture_incorrect_flow_cell_path_extension(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_extension: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_extension)


@pytest.fixture(name="non-existent_flow_cell_path", scope="function")
def fixture_non_existent_flow_cell_path(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_name: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_name)

==> cg-47.0.0.tar.gz: cg-47.0.0/tests/meta/clean/conftest.py <==
from pathlib import Path

import pytest


@pytest.fixture(scope="function")
def correct_flow_cell_name(bcl2fastq_flow_cell_full_name: str) -> str:
    """Correct flow cell name."""
    return bcl2fastq_flow_cell_full_name


@pytest.fixture(scope="function")
def incorrect_flow_cell_too_long(correct_flow_cell_name: str) -> str:
    """Incorrect flow cell name."""
    return correct_flow_cell_name + "_r"


@pytest.fixture(scope="function")
def incorrect_flow_cell_extension(correct_flow_cell_name: str) -> str:
    """Incorrect flow cell name."""
    return correct_flow_cell_name + ".someextension"


@pytest.fixture(scope="function")
def incorrect_flow_cell_name() -> str:
    """Incorrect flow cell name."""
    return "201203_A00689_0200_AZZZZZZZZZ"


@pytest.fixture(scope="function")
def correct_flow_cell_path(
    tmp_demultiplexed_runs_directory: Path, correct_flow_cell_name: str
) -> Path:
    """Full path to a correctly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, correct_flow_cell_name)


@pytest.fixture(scope="function")
def incorrect_flow_cell_path_too_long(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_too_long: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_too_long)


@pytest.fixture(scope="function")
def incorrect_flow_cell_path_extension(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_extension: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_extension)


@pytest.fixture(name="non-existent_flow_cell_path", scope="function")
def non_existent_flow_cell_path(
    tmp_demultiplexed_runs_directory: Path, incorrect_flow_cell_name: str
) -> Path:
    """Full path to an incorrectly named flow cell directory in demultiplexed-runs."""
    return Path(tmp_demultiplexed_runs_directory, incorrect_flow_cell_name)
